@@ -129,7 +129,7 @@ cnd_names_non_null <- function(name) {
 cnd_names_non_na <- function(name) {
   bad_name <- which(is.na(name))
   if (has_length(bad_name)) {
-    error_column_names_cannot_be_empty(bad_name)
+    error_column_names_cannot_be_empty(bad_name, repair_hint = FALSE)
   } else {
     invisible()
   }
@@ -137,8 +137,8 @@ cnd_names_non_na <- function(name) {
 
 # Errors ------------------------------------------------------------------
 
-error_names_must_be_non_null <- function(repair = has_tibble_arg(".name_repair")) {
-  tibble_error(paste0("`names` must not be `NULL`.", use_repair(repair)))
+error_names_must_be_non_null <- function() {
+  tibble_error("`names` must not be `NULL`.")
 }
 
 error_names_must_have_length <- function(length, n) {
