@@ -6,12 +6,12 @@
 #' For a list, the result will be a nested tibble with a column of type `list`.
 #' For unnamed vectors, the natural sequence is used as name column.
 #'
-#' @param x An atomic vector (for `enframe()`) or a data frame with one or two columns
+#' @param x A vector (for `enframe()`) or a data frame with one or two columns
 #'   (for `deframe()`).
 #' @param name,value Names of the columns that store the names and values.
 #'   If `name` is `NULL`, a one-column tibble is returned; `value` cannot be `NULL`.
 #'
-#' @return A [tibble] with two columns (if `name` is not `NULL`, the default)
+#' @return Fpr `enframe()`, a [tibble] with two columns (if `name` is not `NULL`, the default)
 #'   or one column (otherwise).
 #' @export
 #'
@@ -24,22 +24,34 @@ enframe <- function(x, name = "name", value = "value") {
     cnd_signal(error_enframe_value_null())
   }
 
-  if (length(dim(x)) > 1) {
-    cnd_signal(error_enframe_has_dim(x))
+  if (is.null(x)) {
+    x <- logical()
   }
 
-  if (is.null(x)) x <- logical()
+  # FIXME: Enable again for data frames, add test
+  if (!vec_is(x) || is.data.frame(x)) {
+    cnd_signal(error_enframe_must_be_vector(x))
+  }
 
   if (is.null(name)) {
-    df <- list(unname(x))
-  } else if (is.null(names(x))) {
-    df <- list(seq_along(x), x)
+    df <- list(vectbl_set_names(x))
+  } else if (is.null(vec_names(x))) {
+    df <- list(seq_len(vec_size(x)), x)
   } else {
-    df <- list(names(x), unname(x))
+    df <- list(vec_names2(x), vectbl_set_names(x))
   }
 
   names(df) <- c(name, value)
-  new_tibble(df, nrow = length(x))
+  new_tibble(df, nrow = vec_size(x))
+}
+
+vectbl_set_names <- function(x, names = NULL) {
+  # Work around https://github.com/r-lib/vctrs/issues/1419
+  if (inherits(x, "vctrs_rcrd")) {
+    # A rcrd can't have names?
+    return(x)
+  }
+  vec_set_names(x, names)
 }
 
 #' @rdname enframe
@@ -47,6 +59,7 @@ enframe <- function(x, name = "name", value = "value") {
 #' `deframe()` converts two-column data frames to a named vector or list,
 #' using the first column as name and the second column as value.
 #' If the input has only one column, an unnamed vector is returned.
+#' @return For `deframe()`, a vector (named or unnamed).
 #' @export
 #' @examples
 #' deframe(enframe(3:1))
@@ -61,14 +74,15 @@ deframe <- function(x) {
 
   value <- x[[2L]]
   name <- x[[1L]]
-  names(value) <- name
-  value
+  vectbl_set_names(value, as.character(name))
 }
 
 error_enframe_value_null <- function() {
   tibble_error("`value` can't be NULL.")
 }
 
-error_enframe_has_dim <- function(x) {
-  tibble_error(paste0("`x` must not have more than one dimension. `length(dim(x))` must be zero or one, not ", length(dim(x)), "."))
+error_enframe_must_be_vector <- function(x) {
+  tibble_error(paste0(
+    "The `x` argument to `enframe()` must be a vector, not ", class(x)[[1]], "."
+  ))
 }
