@@ -21,9 +21,11 @@ test_that("names<-()", {
   scoped_lifecycle_warnings()
 
   if (!is_rstudio()) {
-    expect_warning(
-      set_tbl_names(NULL),
-      class = "lifecycle_warning_deprecated"
+    suppressWarnings(
+      expect_warning(
+        set_tbl_names(NULL),
+        class = "lifecycle_warning_deprecated"
+      )
     )
   }
 
@@ -46,10 +48,15 @@ test_that("names<-()", {
   )
 })
 
-verify_output("class-tbl_df.txt", {
-  df <- tibble(a = 1, b = 2)
+test_that("output test", {
+  skip_if_not_installed("testthat", "3.0.0.9000")
+  skip_if_not_installed("lifecycle", "0.2.0.9000")
 
-  names(df) <- NULL
-  names(df) <- "c"
-  names(df) <- c("..1", "..2")
+  expect_snapshot({
+    df <- tibble(a = 1, b = 2)
+
+    names(df) <- NULL
+    names(df) <- "c"
+    names(df) <- c("..1", "..2")
+  })
 })
