@@ -1,17 +1,14 @@
-context("Truncated matrix")
-
 test_that("print() returns output invisibly", {
   expect_output(ret <- withVisible(print(as_tibble(iris))))
   expect_false(ret$visible)
   expect_identical(ret$value, as_tibble(iris))
 })
 
-test_that("trunc_mat header output", {
-  skip_on_non_utf8_locale()
+test_that("output test", {
   skip_if_not_installed("mockr")
-  testthat::skip_if(getRversion() < "3.2")
+  skip_if(getRversion() < "3.2")
 
-  verify_output("trunc_mat.txt", unicode = TRUE, {
+  expect_snapshot({
     mtcars2 <- as_tibble(mtcars, rownames = NA)
 
     print_without_body(mtcars2, n = 8L, width = 30L)
@@ -63,11 +60,12 @@ test_that("trunc_mat header output", {
   })
 })
 
-test_that("trunc_mat output matches known output", {
-  skip_on_non_utf8_locale()
-  testthat::skip_if(getRversion() < "3.2")
+test_that("full output test", {
+  skip_if(getRversion() < "3.2")
+  skip_on_os("windows")
+  skip_on_os("mac")
 
-  verify_output("trunc_mat_full.txt", unicode = TRUE, {
+  expect_snapshot({
     df <- tibble(x = as.POSIXct("2016-01-01 12:34:56 GMT") + 1:12)
     df$y <- as.POSIXlt(df$x)
 
