@@ -481,6 +481,12 @@ test_that("[[<-.tbl_df requires scalar, positive if numeric", {
   expect_error(df[[-1]] <- 1, class = "vctrs_error_subscript_type")
 })
 
+test_that("[[<-.tbl_df supports symbols (#691)", {
+  foo <- tibble(x = 1:10, y = 1:10)
+  foo[[quote(x)]] <- 10:1
+  expect_identical(foo$x, 10:1)
+})
+
 # [<- ---------------------------------------------------------------------
 
 test_that("[<-.tbl_df can remove columns", {
@@ -918,8 +924,49 @@ test_that("output test", {
     df[1:3, 1:3] <- NULL
 
     "# [<-.tbl_df and overwriting NA"
-    df <- tibble(x = rep(NA, 3))
+    df <- tibble(x = rep(NA, 3), z = matrix(NA, ncol = 2, dimnames = list(NULL, c("a", "b"))))
     df[1, "x"] <- 5
+    df[1, "z"] <- 5
+    df
+
+    "# [<-.tbl_df and overwriting with NA"
+    df <- tibble(
+      a = TRUE,
+      b = 1L,
+      c = sqrt(2),
+      d = 3i + 1,
+      e = "e",
+      f = raw(1),
+      g = tibble(x = 1, y = 1),
+      h = matrix(1:3, nrow = 1)
+    )
+    df[FALSE, "a"] <- NA
+    df[FALSE, "b"] <- NA
+    df[FALSE, "c"] <- NA
+    df[FALSE, "d"] <- NA
+    df[FALSE, "e"] <- NA
+    df[FALSE, "f"] <- NA
+    df[FALSE, "g"] <- NA
+    df[FALSE, "h"] <- NA
+    df
+    df[integer(), "a"] <- NA
+    df[integer(), "b"] <- NA
+    df[integer(), "c"] <- NA
+    df[integer(), "d"] <- NA
+    df[integer(), "e"] <- NA
+    df[integer(), "f"] <- NA
+    df[integer(), "g"] <- NA
+    df[integer(), "h"] <- NA
+    df
+    df[1, "a"] <- NA
+    df[1, "b"] <- NA
+    df[1, "c"] <- NA
+    df[1, "d"] <- NA
+    df[1, "e"] <- NA
+    df[1, "f"] <- NA
+    df[1, "g"] <- NA
+    df[1, "h"] <- NA
+    df
 
     "# [<-.tbl_df and matrix subsetting"
     foo <- tibble(a = 1:3, b = letters[1:3])
